<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>关于 %1</translation>
    </message>
    <message>
        <source>&lt;h4&gt;Seafile Drive Client %2&lt;/h4&gt;</source>
        <translation>&lt;h4&gt;Seafile 挂载盘客户端 %2&lt;/h4&gt;</translation>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation>&lt;h5&gt; 版本 %1 &lt;/h5&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>打开账号数据库失败</translation>
    </message>
</context>
<context>
    <name>AutoLogonDialog</name>
    <message>
        <source>auto login</source>
        <translation>自动登录</translation>
    </message>
    <message>
        <source>auto logining, please wait a moment</source>
        <translation>正在登录，请稍候</translation>
    </message>
    <message>
        <source>Please input server address</source>
        <translation>请输入服务器地址</translation>
    </message>
    <message>
        <source>address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>请输入服务器地址</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 不是一个合法的服务器地址</translation>
    </message>
    <message>
        <source>login failed</source>
        <translation>登录失败</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 failed to initialize</source>
        <translation>%1 初始化时出错</translation>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation>%1 意外退出</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create seadrive mount folder</source>
        <translation>初始化失败：无法创建 SeaDrive 顶层目录</translation>
    </message>
</context>
<context>
    <name>EncryptedReposDialog</name>
    <message>
        <source>Encrypted Libraries</source>
        <translation>加密资料库</translation>
    </message>
    <message>
        <source>No Encrypted Library.</source>
        <translation>没有加密资料库</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableModel</name>
    <message>
        <source>Failed to set encrypted library password</source>
        <translation>设置加密资料库密码失败</translation>
    </message>
    <message>
        <source>Password error</source>
        <translation>密码错误</translation>
    </message>
    <message>
        <source>Failed to clear encrypted library password</source>
        <translation>清除加密资料库密码失败</translation>
    </message>
    <message>
        <source>Right click this item to sync or unsync the encrypted library</source>
        <translation>右击该条目同步或解除同步加密资料库</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>资料库</translation>
    </message>
    <message>
        <source>Sync status</source>
        <translation>同步状态</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>服务器</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
</context>
<context>
    <name>EncryptedReposTableView</name>
    <message>
        <source>Unsync</source>
        <translation>解除同步</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>同步</translation>
    </message>
    <message>
        <source>After unsyncing, the local encryption key of this library will be cleared and this library cannot be accessed in virtual drive. Are you sure to unsync?</source>
        <translation>解除同步后会清除本地的资料库秘钥，且不会在虚拟盘中列出该资料库。确认解除同步？</translation>
    </message>
    <message>
        <source>Enter library password to sync</source>
        <translation>输入资料库密码同步加密资料库</translation>
    </message>
</context>
<context>
    <name>ExtCommandsHandler</name>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>是否删除账号 %1 ？已下载和正在上传的文件会被保留。</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>无法连接后台进程，请稍后重试</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>是否重新同步账号 %1 ？已下载和正在上传的文件会被保留。</translation>
    </message>
</context>
<context>
    <name>FileProviderManager</name>
    <message>
        <source>%1 will ask permissions to enable Finder plugin.</source>
        <translation>%1 将请求系统权限，用以启用“访达”扩展。</translation>
    </message>
</context>
<context>
    <name>FilterMenu</name>
    <message>
        <source>FilterMenu</source>
        <translation>FilterMenu</translation>
    </message>
    <message>
        <source>Text file    </source>
        <translation>文本文件</translation>
    </message>
    <message>
        <source>Document    </source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Image    </source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Video    </source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Audio    </source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Markdown</source>
        <translation>Markdown</translation>
    </message>
</context>
<context>
    <name>InitSyncDialog</name>
    <message>
        <source>Download files list</source>
        <translation>获取文件列表</translation>
    </message>
    <message>
        <source>%1 is fetching the files list, please wait</source>
        <translation>%1 正在获取文件列表, 请稍候</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>图标</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>后台运行</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>%1 has downloaded your files list.</source>
        <translation>%1 已经完成文件列表获取。</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation>加载更多</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>添加账号</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation>单点登录</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>重新登录</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>登录中...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>网络错误：
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;警告:&lt;/b&gt; 该服务器的SSL 证书不可信，是否继续？</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>请输入云盘网址</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 不是合法的云盘网址</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>请输入邮箱</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>请填写计算机名</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation>两步验证</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation>%1 云盘网址</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation>请输入两步验证的动态口令</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>错误的邮箱或密码</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>登录过于频繁，请稍后再试</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>服务器内部错误</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>登录失败：%1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>登录失败</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>标志</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>云盘网址：</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>或者 http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation>自动登录</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>状态文本</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>计算机名：</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>邮箱 / 用户名:</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>例如：小王的工作笔记本</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登录</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Failed to get server info. Please check the server address.</source>
        <translation>获取服务器数据失败。请检查服务器地址。</translation>
    </message>
    <message>
        <source>Failed to get client sso link.</source>
        <translation>获取客户端单点登录链接失败。</translation>
    </message>
    <message>
        <source>SSO login failed.</source>
        <translation>单点登录失败。</translation>
    </message>
    <message>
        <source>Failed to get client sso status.</source>
        <translation>获取客户端单点登录状态失败。</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;例如：https://cloud.seafile.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation>高级选项</translation>
    </message>
    <message>
        <source>Sync Root Folder Name:</source>
        <translation>根目录名称：</translation>
    </message>
    <message>
        <source>Sync root folder name cannot be empty</source>
        <translation>根目录名称不能为空</translation>
    </message>
    <message>
        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
        <translation>根目录名称不能包含以下字符：&lt; &gt; : &quot; / \ | ? *</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;账号中的文件会被同步到以下路径：C:\Users\Jim\seadrive_root\&lt;根目录名称&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; 已同步</translation>
    </message>
    <message>
        <source>Error when syncing &quot;%1&quot;</source>
        <translation>同步 “%1” 时出错</translation>
    </message>
    <message>
        <source>Error when syncing</source>
        <translation>同步文件时出错</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is being uploaded</source>
        <translation>正在上传 “%1”</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot;</source>
        <translation>开始移动 “%1”</translation>
    </message>
    <message>
        <source>Starting to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>开始移动“%1”到“%2”</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot;</source>
        <translation>成功移动 “%1”</translation>
    </message>
    <message>
        <source>Successfully moved &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>成功移动“%1”到“%2”</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot;</source>
        <translation>移动 “%1” 时出错</translation>
    </message>
    <message>
        <source>Failed to move &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>移动“%1”到“%2”时出错</translation>
    </message>
    <message>
        <source>Download file</source>
        <translation>下载文件</translation>
    </message>
    <message>
        <source>Start to download file &quot;%1&quot; </source>
        <translation>开始下载文件 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>file &quot;%1&quot; has been downloaded </source>
        <translation>文件 &quot;%1&quot; 已经下载完成</translation>
    </message>
    <message>
        <source>Failed to create file &quot;%1&quot;</source>
        <translation>创建文件 “%1” 时失败</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation>删除目录时出错</translation>
    </message>
    <message>
        <source>You can&apos;t delete the library &quot;%1&quot; directly</source>
        <translation>不能直接删除资料库 “%1”</translation>
    </message>
    <message>
        <source>Libraries are ready</source>
        <translation>资料库准备就绪</translation>
    </message>
    <message>
        <source>All libraries are loaded and ready to use.</source>
        <translation>所有资料库已加载完毕并可以使用</translation>
    </message>
    <message>
        <source>Deleted &quot;%1&quot; and %2 more files.</source>
        <translation>删除了 “%1” 以及其它 %2 个文件</translation>
    </message>
    <message>
        <source>You can&apos;t create files in the mount folder directly</source>
        <translation>无法在顶层目录下创建文件</translation>
    </message>
    <message>
        <source>Do you want to delete files in library &quot;%1&quot; ?</source>
        <translation>确认删除 “%1” 资料库中的文件？</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>删除了资料库 “%1”</translation>
    </message>
    <message>
        <source>Confirm to delete library &quot;%1&quot; ?</source>
        <translation>确认删除资料库 “%1” ？</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>File %1 is locked by other programs</source>
        <translation>文件 %1 已被其它应用程序锁定</translation>
    </message>
    <message>
        <source>Some file is locked by other programs</source>
        <translation>某个文件已被其它应用程序锁定</translation>
    </message>
    <message>
        <source>Folder %1 is locked by other programs</source>
        <translation>文件夹 %1 已被其它应用程序锁定</translation>
    </message>
    <message>
        <source>Some folder is locked by other programs</source>
        <translation>某个文件夹已被其它应用程序锁定</translation>
    </message>
    <message>
        <source>File %1 is locked by another user</source>
        <translation>文件 %1 已被另一个用户锁定</translation>
    </message>
    <message>
        <source>Some file is locked by another user</source>
        <translation>某个文件已被另一个用户锁定</translation>
    </message>
    <message>
        <source>Invalid path %1</source>
        <translation>非法的路径 %1</translation>
    </message>
    <message>
        <source>Trying to access an invalid path</source>
        <translation>尝试访问非法路径</translation>
    </message>
    <message>
        <source>Error when indexing file %1</source>
        <translation>索引文件 %1 时出错</translation>
    </message>
    <message>
        <source>Error when indexing files</source>
        <translation>索引文件时出错</translation>
    </message>
    <message>
        <source>You don&apos;t have enough permission for this library</source>
        <translation>你没有访问该资料库的足够权限</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <source>Failed to resolve network proxy</source>
        <translation>代理解析出错</translation>
    </message>
    <message>
        <source>Failed to resolve remote server</source>
        <translation>服务器地址解析出错</translation>
    </message>
    <message>
        <source>Failed to connect to server</source>
        <translation>连接服务器时出错</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>SSL 错误</translation>
    </message>
    <message>
        <source>Error in network transmission</source>
        <translation>网络传输时出错</translation>
    </message>
    <message>
        <source>Timeout in network transmission</source>
        <translation>网络传输超时</translation>
    </message>
    <message>
        <source>Failed to handle http redirection</source>
        <translation>处理 HTTP 重定向时出错</translation>
    </message>
    <message>
        <source>Server internal error</source>
        <translation>服务器内部错误</translation>
    </message>
    <message>
        <source>Local data is corrupt</source>
        <translation>本地数据损坏</translation>
    </message>
    <message>
        <source>Failed to write local data</source>
        <translation>写入本地数据时出错</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>该用户的空间已经用完</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL 错误</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>网络错误：%1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>服务器内部错误</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>创建了资料库 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>删除了资料库 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>添加了</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>删除了</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>删除了</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>修改了</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>重命名了</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>添加或修改了</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>移动了</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>添加了文件夹</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>删除了文件夹</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>重命名了文件夹</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>移动了文件夹</translation>
    </message>
    <message>
        <source>files</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>及其他 %1 个</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>资料库状态恢复到</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>文件 &quot;%1&quot; 状态恢复到 %2。</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>恢复了删除的文件夹</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>更改了资料库的名字或描述</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation>系统自动合并更改</translation>
    </message>
    <message>
        <source>Just now</source>
        <translation>刚才</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 天前</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 天前</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 小时前</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 小时前</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 分钟前</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 分钟前</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>只读文件夹</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF 文档</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>文本文件</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>音乐文件</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>视频文件</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word文档</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint文档</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel文档</translation>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation>已经有一个 %1 客户端在运行中</translation>
    </message>
    <message>
        <source>Choose the disk letter for %1</source>
        <translation>为 %1 选择盘符</translation>
    </message>
    <message>
        <source>Update to file %1 denied by folder permission setting</source>
        <translation>文件夹权限设置拒绝更新文件 ％1</translation>
    </message>
    <message>
        <source>Path %1 ends with space or period character</source>
        <translation>路径 %1 以空格或句点字符结尾</translation>
    </message>
    <message>
        <source>Path %1 contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation>路径 %1 包含无效字符，例如 &apos;|&apos; 或 ‘:’</translation>
    </message>
    <message>
        <source>Created or updated a file %1 in a non-writable library or folder</source>
        <translation>在只读资料库或文件夹中创建或更新文件 %1</translation>
    </message>
    <message>
        <source>Concurrent updates to file %1. File is saved as conflict file</source>
        <translation>同时更新文件 %1。文件另存为冲突文件</translation>
    </message>
    <message>
        <source>%1 is not added to a library and will not be uploaded</source>
        <translation>%1 没有被添加到资料库文件夹中，因此不会被上传</translation>
    </message>
    <message>
        <source>You can only move files/folders within a library or from one library to another library</source>
        <translation>您只能将文件、文件夹在一个资料库内移动，或者从一个资料库移动到另一个资料库。</translation>
    </message>
    <message>
        <source>Syncing is denied by cloud-only permission settings</source>
        <translation>设置了仅云端访问的权限导致无法同步</translation>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation>对资料库没有写入权限</translation>
    </message>
    <message>
        <source>Waiting for confirmation to delete files</source>
        <translation>等待确认文件删除操作</translation>
    </message>
    <message>
        <source>The path %1 contains symbols that are not supported by the Windows system.</source>
        <translation>文件路径 %1 包含 Windows 系统不支持的符号。</translation>
    </message>
    <message>
        <source>Failed to upload file blocks. Please check network or firewall.</source>
        <translation>上传文件块失败，请检查网络和防火墙的状态</translation>
    </message>
    <message>
        <source>Failed to download file. Please check disk space or folder permissions</source>
        <translation>下载文件失败，请检查磁盘空间和目录权限。</translation>
    </message>
    <message>
        <source>Library cannot be synced since it has too many files.</source>
        <translation>资料库文件太多，无法进行同步。</translation>
    </message>
    <message>
        <source>Files cannot be uploaded to this library due to file number limit settings.</source>
        <translation>由于资料库文件数限制，文件无法上传。</translation>
    </message>
    <message>
        <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
        <translation>同步路径与现存文件或目录存在大小写冲突，下载已跳过</translation>
    </message>
    <message>
        <source>Failed to change library name since some files are opened in it</source>
        <translation>无法修改资料库名称，部分文件正在使用中</translation>
    </message>
</context>
<context>
    <name>RemoteWipeService</name>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>账号验证信息已过期，请重新登录</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login. You can find files that are not uploaded yet at ~/Library/CloudStorage</source>
        <translation>账号验证信息已过期，请重新登录。您可以在 “资源库/CloudStorage” 目录里找到未上传的文件。</translation>
    </message>
</context>
<context>
    <name>SeaDriveRootDialog</name>
    <message>
        <source>Choose SeaDrive Cache Folder</source>
        <translation>选择 SeaDrive 缓存目录</translation>
    </message>
    <message>
        <source>Your files will appear in a local cache folder. Please choose the folder:</source>
        <translation>您的文件将出现在本地缓存目录中，请选择此目录：</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder </source>
        <translation>选择 %1 的缓存目录</translation>
    </message>
    <message>
        <source>Choose %1 Cache Folder</source>
        <translation>选择 %1 的缓存目录</translation>
    </message>
    <message>
        <source>Please choose %1 cache folder</source>
        <translation>请选择 %1 的缓存目录</translation>
    </message>
    <message>
        <source>Create %1 folder failed!</source>
        <translation>创建 %1 目录失败！</translation>
    </message>
</context>
<context>
    <name>SeadriveGui</name>
    <message>
        <source>Failed to initialize log: %1</source>
        <translation>初始化日志时出错: %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation>保存客户端 ID 时出错</translation>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation>访问 %1 时出错</translation>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation>错误的客户端 ID</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>读取 %1 时出错</translation>
    </message>
    <message>
        <source>Auto logon failed, fall back to manual login</source>
        <translation>自动登录失败，请手动登录</translation>
    </message>
    <message>
        <source>Faild to choose a cache directory</source>
        <translation>选择缓存目录失败</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 folder</source>
        <translation>初始化失败： 创建 %1 文件夹失败</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 logs folder</source>
        <translation>初始化失败：创建 %1 日志文件夹失败</translation>
    </message>
    <message>
        <source>Failed to initialize: failed to create %1 data folder</source>
        <translation>初始化失败：创建 %1 数据数据文件夹失败</translation>
    </message>
    <message>
        <source>Failed to create seadrive cache directory</source>
        <translation>创建缓存目录失败</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Faild to migrate old data</source>
        <translation>迁移旧数据失败</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 多账号功能不兼容 macOS 14.4 以下版本。请升级您的 macOS 系统或者安装 SeaDrive 3.0.9 版本。</translation>
    </message>
    <message>
        <source>To start %1 extension for account %2, you need to click the %3 entry in Finder</source>
        <translation>请点击访达里的 %3 ，来启动 %2 账号的 %1 扩展</translation>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get upload link information for file &quot;%1&quot;</source>
        <translation>获取文件 “ %1 ” 的上传链接信息失败</translation>
    </message>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>没有权限创建共享链接</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>获取内部链接失败 %1</translation>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation>锁定文件失败</translation>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation>解锁文件失败</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation>文件 “ %1 ” 被 %2 锁定</translation>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation>获取文件 “ %1 ” 的锁定信息失败</translation>
    </message>
    <message>
        <source>Failed to get share link %1
</source>
        <translation>获取共享链接失败 %1
</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation>%1 内部链接</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制至剪贴板</translation>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation>%1 内部链接：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>internal error: failed to connect to %1 daemon</source>
        <translation>内部错误：连接 %1 守护进程失败</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation>查看文件同步错误</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>打开日志文件夹(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>显示关于对话框</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>在线帮助(&amp;O)</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation>账号</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>未登录</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>添加账号</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Seafile Drive Client %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Seafile Drive 客户端 %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>Up %1, Down %2</source>
        <translation>上传 %1，下载 %2</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>关于 %1</translation>
    </message>
    <message>
        <source>Transfer progress</source>
        <translation>传输进度</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>打开 %1 日志文件夹</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>打开 %1 在线帮助文档</translation>
    </message>
    <message>
        <source>Show encrypted libraries</source>
        <translation>显示加密资料库</translation>
    </message>
    <message>
        <source>Starting ...</source>
        <translation>正在启动 ...</translation>
    </message>
    <message>
        <source>Resync</source>
        <translation>重新同步</translation>
    </message>
    <message>
        <source>There are changes being uploaded under the account, please try again later</source>
        <translation>部分修改正在同步中，请稍后重试</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? After removing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>是否删除账号 %1 ？删除账号后，已下载的文件仍保留在 ~/Library/CloudStorage 目录。</translation>
    </message>
    <message>
        <source>Failed to connect to background process, please try again later</source>
        <translation>无法连接后台进程，请稍后重试</translation>
    </message>
    <message>
        <source>SeaDrive %1 with multiple accounts cannot work with macOS version lower than 14.4. Please upgrade your macOS or downgrade SeaDrive to 3.0.9</source>
        <translation>SeaDrive %1 多账号功能不兼容 macOS 14.4 以下版本。请升级您的 macOS 系统或者安装 SeaDrive 3.0.9 版本。</translation>
    </message>
    <message>
        <source>Search files</source>
        <translation>搜索文件</translation>
    </message>
    <message>
        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
        <translation>是否删除账号 %1 ？已下载和正在上传的文件会被保留。</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
        <translation>是否重新同步账号 %1 ？已下载和正在上传的文件会被保留。</translation>
    </message>
    <message>
        <source>Are you sure to resync account from &quot;%1&quot;? After resyncing account, you can still find downloaded files at ~/Library/CloudStorage.</source>
        <translation>是否重新同步账号 %1 ？重新同步后，原先已下载的文件保留在 ~/Library/CloudStorage 目录。</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search files</source>
        <translation>搜索文件</translation>
    </message>
    <message>
        <source>All file types</source>
        <translation>所有文件类型</translation>
    </message>
    <message>
        <source>Custom file type</source>
        <translation>自定义文件类型</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation>搜索失败&lt;br/&gt;请%1</translation>
    </message>
    <message>
        <source>No result found</source>
        <translation>未找到结果</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableModel</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>类型</translation>
    </message>
</context>
<context>
    <name>SearchItemsTableView</name>
    <message>
        <source>&amp;Open the file</source>
        <translation>&amp;打开文件</translation>
    </message>
    <message>
        <source>&amp;Show in folder</source>
        <translation>&amp;在文件夹里显示</translation>
    </message>
    <message>
        <source>File not found, maybe not synchorized yet</source>
        <translation>未找到文件，可能尚未同步</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation>开机自动启动 %1</translation>
    </message>
    <message>
        <source>Cache directory:</source>
        <translation>缓存目录：</translation>
    </message>
    <message>
        <source>Enable search</source>
        <translation>启用搜索</translation>
    </message>
    <message>
        <source>None</source>
        <translation>没有代理</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP 代理</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>SOCKS5 代理</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <source>enabled search</source>
        <translation>启用搜索</translation>
    </message>
    <message>
        <source>disabled search</source>
        <translation>禁用搜索</translation>
    </message>
    <message>
        <source>You have %1. Restart to apply it?</source>
        <translation>您已经 %1。现在重启来生效吗？</translation>
    </message>
    <message>
        <source>Please choose the cache folder</source>
        <translation>请选择缓存目录</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation>代理服务器名不能为空</translation>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation>代理端口不正确</translation>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation>代理用户名不能为空</translation>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation>代理用户密码不能为空</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>资料库同步后用气泡通知</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>允许同步 office 临时文件</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>最大下载速度 (kB/s)：</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>最大上传速度 (kB/s)：</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基本</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>启用文件浏览器的扩展</translation>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>HTTPS 同步过程中不验证服务器证书</translation>
    </message>
    <message>
        <source>Cache clean interval (in minutes):</source>
        <translation>缓存定期清理间隔 (分钟)</translation>
    </message>
    <message>
        <source>Cache size limit (in GB):</source>
        <translation>最大缓存容量: (GB)</translation>
    </message>
    <message>
        <source>select...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>语言 (需要重启)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>代理类型：</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主机：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>代理服务器需要密码</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Enable search in finder</source>
        <translation>Finder中启用搜索</translation>
    </message>
    <message>
        <source>You have changed language, Restart to apply it?</source>
        <translation>您已改变语言， 是否重启使其生效？</translation>
    </message>
    <message>
        <source>You have changed cache directory. Restart to apply it?</source>
        <translation>您已经修改缓存目录。 是否重启使其生效？</translation>
    </message>
    <message>
        <source>You have changed %1 cache folder. Restart to apply it?</source>
        <translation>你已经修改了 %1 缓存文件夹失败。重启应用使其生效</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Hide Windows incompatibility paths Message</source>
        <translation>隐藏文件路径不兼容 Windows 系统的提示</translation>
    </message>
    <message>
        <source>Confirm before deleting files more than</source>
        <translation>提示确认操作，当删除的文件数大于</translation>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>共享链接</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>共享链接:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>直接下载</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制至剪贴板</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>显示密码</translation>
    </message>
    <message>
        <source>Expire days</source>
        <translation>过期天数</translation>
    </message>
    <message>
        <source>Generate link</source>
        <translation>生成链接</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Failed to generate share link: %1</source>
        <translation>生成共享链接失败：%1</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Single Sign On</source>
        <translation>单点登录或微信登录</translation>
    </message>
</context>
<context>
    <name>SyncCommand</name>
    <message>
        <source>No permissions to create a shared link</source>
        <translation>没有权限创建共享链接</translation>
    </message>
    <message>
        <source>failed to get share link %1</source>
        <translation>获取共享链接失败 %1</translation>
    </message>
    <message>
        <source>failed get internal link %1</source>
        <translation>获取内部链接失败 %1</translation>
    </message>
    <message>
        <source>Failed to get upload link for file &quot;%1&quot;</source>
        <translation>获取文件 “%1” 的上传链接失败</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation>文件同步错误</translation>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation>没有同步错误。</translation>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation>双击来打开该资料库</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>资料库</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>时间</translation>
    </message>
</context>
<context>
    <name>TransferItemsTableModel</name>
    <message>
        <source>finished</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>文件名</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>服务器</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
</context>
<context>
    <name>TransferProgressDialog</name>
    <message>
        <source>Transfer Progress</source>
        <translation>传输进度</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上传</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>卸载 %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>你想删除 %1 的账号信息吗？</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>删除账号信息...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
</context>
<context>
    <name>UploadLinkDialog</name>
    <message>
        <source>Upload Link</source>
        <translation>上传链接</translation>
    </message>
    <message>
        <source>Upload link:</source>
        <translation>上传链接：</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>复制到剪贴板</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
</TS>